Documentation
¶
Overview ¶
Package localauth provides Go bindings for Apple's LocalAuthentication SwiftUI cross-import overlay (_LocalAuthentication_SwiftUI).
This overlay provides SwiftUI views and modifiers that integrate LocalAuthentication with SwiftUI. All view constructors return uintptr values suitable for use with swiftui.ViewFromPointer.
Bridge sources under internal/swift/ are generated by go generate.
Threading ¶
All bridge functions dispatch to the main thread internally. The Go API is safe to call from any goroutine.
Quick start ¶
import "github.com/tmc/swiftui" import "github.com/tmc/swiftui/localauth" ptr := localauth.NewLocalAuthView(...) view := swiftui.ViewFromPointer(ptr)
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewLocalAuthView ¶
NewLocalAuthView creates a LocalAuthenticationView with the given reason string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.